==> apache-log4j-2.21.0-src.zip: log4j-core-test/src/main/java/org/apache/logging/log4j/core/test/net/mock/MockSyslogServerFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.core.test.net.mock;

import java.io.IOException;
import java.net.SocketException;

import javax.net.ssl.SSLServerSocket;

import org.apache.logging.log4j.core.test.net.ssl.TlsSyslogMessageFormat;

public class MockSyslogServerFactory {

    public static MockSyslogServer createUDPSyslogServer(final int numberOfMessagesToReceive, final int port)
            throws SocketException {
        return new MockUdpSyslogServer(numberOfMessagesToReceive, port);
    }

    public static MockSyslogServer createUDPSyslogServer() throws SocketException {
        return new MockUdpSyslogServer();
    }

    public static MockSyslogServer createTCPSyslogServer(final int numberOfMessagesToReceive, final int port)
            throws IOException {
        return new MockTcpSyslogServer(numberOfMessagesToReceive, port);
    }

    public static MockSyslogServer createTCPSyslogServer() throws IOException {
        return new MockTcpSyslogServer();
    }

    public static MockSyslogServer createTLSSyslogServer(final int numberOfMessagesToReceive, final TlsSyslogMessageFormat format, final SSLServerSocket serverSocket) {
        return new MockTlsSyslogServer(numberOfMessagesToReceive, format, serverSocket);
   }
}

==> apache-log4j-2.25.2-src.zip: log4j-core-test/src/main/java/org/apache/logging/log4j/core/test/net/mock/MockSyslogServerFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.core.test.net.mock;

import java.io.IOException;
import java.net.SocketException;
import javax.net.ssl.SSLServerSocket;
import org.apache.logging.log4j.core.test.net.ssl.TlsSyslogMessageFormat;

public class MockSyslogServerFactory {

    public static MockSyslogServer createUDPSyslogServer(final int numberOfMessagesToReceive, final int port)
            throws SocketException {
        return new MockUdpSyslogServer(numberOfMessagesToReceive, port);
    }

    public static MockSyslogServer createUDPSyslogServer() throws SocketException {
        return new MockUdpSyslogServer();
    }

    public static MockSyslogServer createTCPSyslogServer(final int numberOfMessagesToReceive, final int port)
            throws IOException {
        return new MockTcpSyslogServer(numberOfMessagesToReceive, port);
    }

    public static MockSyslogServer createTCPSyslogServer() throws IOException {
        return new MockTcpSyslogServer();
    }

    public static MockSyslogServer createTLSSyslogServer(
            final int numberOfMessagesToReceive,
            final TlsSyslogMessageFormat format,
            final SSLServerSocket serverSocket) {
        return new MockTlsSyslogServer(numberOfMessagesToReceive, format, serverSocket);
    }
}
